@@ -1,10 +1,10 @@
-/* $Id: fap.c 227 2015-01-31 12:27:07Z oh2gve $
+/* $Id: fap.c 203 2011-11-20 05:50:04Z oh2gve $
  *
- * Copyright 2005-2012 Tapio Sokura
- * Copyright 2007-2012 Heikki Hannikainen
+ * Copyright 2005, 2006, 2007, 2008, 2009, 2010 Tapio Sokura
+ * Copyright 2007, 2008, 2009, 2010 Heikki Hannikainen
  *
  * Perl-to-C modifications
- * Copyright 2009-2014 Tapio Aaltonen
+ * Copyright 2009, 2010, 2011 Tapio Aaltonen
  *
  * This file is part of libfap.
  *
@@ -126,7 +126,6 @@ regex_t fapint_regex_wx_snow, fapint_regex_wx_rrc, fapint_regex_wx_any, fapint_r
 regex_t fapint_regex_nmea_chksum, fapint_regex_nmea_dst, fapint_regex_nmea_time, fapint_regex_nmea_date;
 regex_t fapint_regex_nmea_specou, fapint_regex_nmea_fix, fapint_regex_nmea_altitude, fapint_regex_nmea_flag, fapint_regex_nmea_coord;
 regex_t fapint_regex_telemetry, fapint_regex_peet_splitter, fapint_regex_kiss_callsign, fapint_regex_kiss_digi;
-regex_t fapint_regex_base91_telemetry;
 
 /* Regex needed in this file. */
 regex_t fapint_regex_detect_comp, fapint_regex_detect_wx, fapint_regex_detect_telem, fapint_regex_detect_exp;
@@ -249,16 +248,12 @@ fap_packet_t* fap_parseaprs(char const* input, unsigned int const input_len, sho
 				result->timestamp = malloc(sizeof(time_t));
 				if ( !result->timestamp ) return result;
 				*result->timestamp = fapint_parse_timestamp(body+1);
-				if ( *result->timestamp == 0 )
+				if ( result->timestamp == NULL )
 				{
 					result->error_code = malloc(sizeof(fap_error_code_t));
 					if ( result->error_code ) *result->error_code = fapTIMESTAMP_INV_LOC;
 					i = 0; /* we has error */
 				}
-				result->raw_timestamp = malloc(7);
-				if ( !result->raw_timestamp ) return result;
-				memcpy(result->raw_timestamp, body+1, 6);
-				result->raw_timestamp[6] = 0;
 				tmp = fapint_remove_part(body, body_len, 0, 8, &body_len);
 				free(body);
 				body = tmp;
@@ -1124,7 +1119,7 @@ int fap_ax25_to_tnc2(char const* ax25frame, unsigned int ax25frame_len,
 				/* Yes, lets do some checks. */
 				if ( header_len < 14 || header_len % 7 != 0 )
 				{
-					sprintf(output, "Invalid header length (%d).", header_len);
+					sprintf(output, "Invalid header lenght (%d).", header_len);
 					output_len = strlen(output)+1;
 					retval = 0;
 					break;
@@ -1161,14 +1156,16 @@ int fap_ax25_to_tnc2(char const* ax25frame, unsigned int ax25frame_len,
 				else if ( header_len == 14 )
 				{
 					/* We have a source callsign, copy it to the final frame directly. */
-					output_len = sprintf(output, "%s>%s", checked_call, dst_callsign);
+					sprintf(output, "%s>%s", checked_call, dst_callsign);
+					output_len = strlen(checked_call) + 1 + strlen(dst_callsign);
 					free(dst_callsign);
 					free(checked_call);
 				}
 				else if ( header_len > 14 )
 				{
 					/* We're at path part, save the call. */
-					output_len += sprintf(output+output_len, "%s", checked_call);
+					sprintf(output+output_len, "%s", checked_call);
+					output_len += strlen(checked_call);
 					free(checked_call);
 					/* Get the has-been-repeated flag. */
 					if ( charri & 0x80 ) 
@@ -1642,8 +1639,6 @@ void fap_init()
 		regcomp(&fapint_regex_hdr_detail, "^([A-Z0-9]{1,6})(-[0-9]{1,2})?>([A-Z0-9]{1,6})(-[0-9]{1,2})?(,.*)?$", REG_EXTENDED);
 		regcomp(&fapint_regex_kiss_digi, "^([A-Z0-9]{1,6})(-[0-9]{1,2})?(\\*)?$", REG_EXTENDED);
 		
-		regcomp(&fapint_regex_base91_telemetry, "\\|([!-{]{2})([!-{]{2})([!-{]{2}|)([!-{]{2}|)([!-{]{2}|)([!-{]{2}|)([!-{]{2}|)\\|", REG_EXTENDED);
-		
 		regcomp(&fapint_regex_hopcount1, "^([A-Z0-9-]+)\\*$", REG_EXTENDED);
 		regcomp(&fapint_regex_hopcount2, "^WIDE([1-7])-([0-7])$", REG_EXTENDED);
 	
@@ -1727,8 +1722,6 @@ void fap_cleanup()
 		regfree(&fapint_regex_hdr_detail);
 		regfree(&fapint_regex_kiss_digi);
 		
-		regfree(&fapint_regex_base91_telemetry);
-		
 		regfree(&fapint_regex_hopcount1);
 		regfree(&fapint_regex_hopcount2);
 		
@@ -1788,7 +1781,6 @@ void fap_free(fap_packet_t* packet)
 	if ( packet->radio_range ) { free(packet->radio_range); }
 	if ( packet->phg ) { free(packet->phg); }
 	if ( packet->timestamp ) { free(packet->timestamp); }
-	if ( packet->raw_timestamp ) { free(packet->raw_timestamp); }
 	if ( packet->nmea_checksum_ok ) { free(packet->nmea_checksum_ok); }
 	
 	if ( packet->wx_report )
@@ -1817,16 +1809,7 @@ void fap_free(fap_packet_t* packet)
 		free(packet->wx_report);
 	}
 	
-	if ( packet->telemetry )
-	{
-		if ( packet->telemetry->seq ) { free(packet->telemetry->seq); }
-		if ( packet->telemetry->val1 ) { free(packet->telemetry->val1); }
-		if ( packet->telemetry->val2 ) { free(packet->telemetry->val2); }
-		if ( packet->telemetry->val3 ) { free(packet->telemetry->val3); }
-		if ( packet->telemetry->val4 ) { free(packet->telemetry->val4); }
-		if ( packet->telemetry->val5 ) { free(packet->telemetry->val5); }
-		free(packet->telemetry);
-	}
+	if ( packet->telemetry ) { free(packet->telemetry); }
 
 	if ( packet->messagebits ) { free(packet->messagebits); }
 	if ( packet->status ) { free(packet->status); }
